diff -Naur u-boot-2006-05-10-1800/lib_microblaze/board.c u-boot-2006-05-10-1800-microblaze/lib_microblaze/board.c
--- u-boot-2006-05-10-1800/lib_microblaze/board.c	2006-05-10 17:43:20.000000000 +0200
+++ u-boot-2006-05-10-1800-microblaze/lib_microblaze/board.c	2006-06-15 21:06:35.000000000 +0200
@@ -1,6 +1,8 @@
 /*
+ * (C) Copyright 2006 Michal Simek
  * (C) Copyright 2004 Atmark Techno, Inc.
  *
+ * Michal  SIMEK <www.monstr.eu>
  * Yasushi SHOJI <yashi@atmark-techno.com>
  *
  * See file CREDITS for list of people who contributed to this
@@ -40,7 +42,6 @@
 static ulong mem_malloc_end;
 static ulong mem_malloc_brk;

-
 void *sbrk (ptrdiff_t increment)
 {
 	ulong old = mem_malloc_brk;
@@ -65,10 +66,29 @@
  * argument, and returns an integer return code, where 0 means
  * "continue" and != 0 means "fatal error, hang the system".
  */
+
+#define DEBUG_BOARD
+
 typedef int (init_fnc_t) (void);
+#ifdef CFG_GPIO_0
+extern void gpio_init(void);
+#endif
+#ifdef CFG_INTC_0
+extern void interrupts_init(void);
+#endif
+#ifdef CFG_TIMER_0
+extern void timer_init(void);
+#endif
+#if (CONFIG_COMMANDS & CFG_CMD_NET)
+extern int eth_init(bd_t * bis);
+extern int getenv_IPaddr(char *);
+#endif

 init_fnc_t *init_sequence[] = {
 	serial_init,		/* serial communications setup */
+#ifdef CFG_GPIO_0
+	gpio_init,
+#endif
 	NULL,
 };
 
@@ -76,24 +96,62 @@
 {
 	bd_t *bd;
 	init_fnc_t **init_fnc_ptr;
-
-	/* Pointer is writable since we allocated a register for it. */
 	gd = (gd_t *)CFG_GBL_DATA_OFFSET;
+	asm("nop"); //must be after init gd- I don't know why - pipeline maybe - without nop not function reset
 	memset((void *)gd, 0, CFG_GBL_DATA_SIZE);
-
 	gd->bd = (bd_t *)(gd+1);	/* At end of global data */
 	gd->baudrate = CONFIG_BAUDRATE;
-
 	bd = gd->bd;
 	bd->bi_baudrate = CONFIG_BAUDRATE;
 
+	bd->bi_memstart = CFG_SDRAM_BASE;
+	bd->bi_memsize = CFG_SDRAM_SIZE;
+#if (CONFIG_COMMANDS & CFG_CMD_FLASH)
+	bd->bi_flashstart= CFG_FLASH_BASE;
+	bd->bi_flashsize= CFG_FLASH_SIZE;
+	bd->bi_flashoffset=CFG_FLASH_BASE+CFG_FLASH_SIZE;
+#ifdef DEBUG_BOARD
+	/* without any op - not function */
+	printf("\n\nU-BOOT for Xilinx ML401 board - Michal Simek\n");
+	printf("\nGlobal struct is from 0x%x to 0x%x,\n stack growing down from 0x%x\n",
+		    CFG_GBL_DATA_OFFSET,CFG_GBL_DATA_OFFSET+CFG_GBL_DATA_SIZE,CFG_INIT_SP_OFFSET);
+#endif /* DEBUG_BOARD */
+/*#ifdef CFG_FLASH_ENV_STORE_START
+	bd->bi_flashenvstart = CFG_FLASH_ENV_STORE_START;
+#else
+	bd->bi_flashenvstart = 0;
+#endif*/ /* CFG_FLASH_ENV_STORE_START */
+#endif /* CFG_CMD_FLASH */
 	for (init_fnc_ptr = init_sequence; *init_fnc_ptr; ++init_fnc_ptr) {
 		WATCHDOG_RESET ();
-		if ((*init_fnc_ptr) () != 0) {
+		if ((*init_fnc_ptr) () != 0) 
+		{
 			hang ();
 		}
 	}
-
+#if (CONFIG_COMMANDS & CFG_CMD_FLASH)
+	flash_init();
+#endif
+	env_init(); 
+#ifdef CFG_INTC_0
+	interrupts_init();
+#endif
+	/* relocate environment function pointers etc. */
+	/* env_relocate() */
+#if (CONFIG_COMMANDS & CFG_CMD_NET)
+	char *s,*e;
+	int i;
+	/* board MAC address */
+	s = getenv ("ethaddr");
+	for (i = 0; i < 6; ++i) {
+		bd->bi_enetaddr[i] = s ? simple_strtoul (s, &e, 16) : 0;
+		if (s)
+			s = (*e) ? e + 1 : e;
+	}
+	/* IP Address */
+	bd->bi_ip_addr = getenv_IPaddr("ipaddr");
+	eth_init(bd);
+#endif
 	/* main_loop */
 	for (;;) {
 		WATCHDOG_RESET ();
